@@ -1,5 +1,6 @@
 import pymysql
 import time
+import logging
 from pymysql import cursors
 from pymyorm.batch import Batch
 
@@ -22,20 +23,20 @@ class Connection(object):
         self.close()
         try:
             if self.__debug:
-                print(str(self.__config))
+                logging.info(str(self.__config))
             self.__autocommit = True
             self.__conn = pymysql.connect(**self.__config, cursorclass=cursors.DictCursor)
             if self.__debug:
-                print('mysql connect success')
+                logging.info('mysql connect success')
         except Exception as e:
             if self.__debug:
-                print('mysql connect error')
+                logging.error('mysql connect error')
             raise e
 
     def close(self):
         if self.__conn is not None:
             if self.__debug:
-                print('mysql connection closed')
+                logging.info('mysql connection closed')
             self.__conn.close()
             self.__conn = None
 
@@ -43,21 +44,23 @@ class Connection(object):
         self.__ping = seconds
 
     def ping(self):
+        if self.__conn is None:
+            return
         current_time = int(time.time())
         if current_time - self.__last_ping_time > self.__ping:
             try:
                 if self.__debug:
-                    print('conn ping')
+                    logging.info('conn ping')
                 self.__conn.ping()
             except Exception as e:
                 if self.__debug:
-                    print(str(e))
+                    logging.error(str(e))
         self.__last_ping_time = int(time.time())
 
     def fetchone(self, sql):
         try:
             if self.__debug:
-                print(f"sql: {sql}")
+                logging.info(f"sql: {sql}")
             if self.__conn is None:
                 self.open(self.__debug)
             self.__conn.autocommit(self.__autocommit)
@@ -66,13 +69,14 @@ class Connection(object):
             result = cursor.fetchone()
             cursor.close()
             return result
-        except pymysql.OperationalError:
+        except pymysql.OperationalError as e:
+            logging.error(str(e))
             self.open(self.__debug)
 
     def fetchall(self, sql):
         try:
             if self.__debug:
-                print(f"sql: {sql}")
+                logging.info(f"sql: {sql}")
             if self.__conn is None:
                 self.open(self.__debug)
             self.__conn.autocommit(self.__autocommit)
@@ -81,26 +85,28 @@ class Connection(object):
             result = cursor.fetchall()
             cursor.close()
             return result
-        except pymysql.OperationalError:
+        except pymysql.OperationalError as e:
+            logging.error(str(e))
             self.open(self.__debug)
 
     def batch(self, sql):
         try:
             if self.__debug:
-                print(f"batch sql: {sql}")
+                logging.info(f"batch sql: {sql}")
             if self.__conn is None:
                 self.open(self.__debug)
             self.__conn.autocommit(self.__autocommit)
             cursor = self.__conn.cursor()
             cursor.execute(sql)
             return Batch(cursor)
-        except pymysql.OperationalError:
+        except pymysql.OperationalError as e:
+            logging.error(str(e))
             self.open(self.__debug)
 
     def insert(self, sql):
         try:
             if self.__debug:
-                print(f"sql: {sql}")
+                logging.info(f"sql: {sql}")
             if self.__conn is None:
                 self.open(self.__debug)
             self.__conn.autocommit(self.__autocommit)
@@ -109,13 +115,14 @@ class Connection(object):
             last_insert_id = cursor.lastrowid
             cursor.close()
             return last_insert_id
-        except pymysql.OperationalError:
+        except pymysql.OperationalError as e:
+            logging.error(str(e))
             self.open(self.__debug)
 
     def insert_batch(self, sql, data):
         try:
             if self.__debug:
-                print(f"sql: {sql}")
+                logging.info(f"sql: {sql}")
             if self.__conn is None:
                 self.open(self.__debug)
             self.__conn.autocommit(self.__autocommit)
@@ -124,13 +131,14 @@ class Connection(object):
             last_insert_id = cursor.lastrowid
             cursor.close()
             return last_insert_id
-        except pymysql.OperationalError:
+        except pymysql.OperationalError as e:
+            logging.error(str(e))
             self.open(self.__debug)
 
     def execute(self, sql):
         try:
             if self.__debug:
-                print(f"sql: {sql}")
+                logging.info(f"sql: {sql}")
             if self.__conn is None:
                 self.open(self.__debug)
             self.__conn.autocommit(self.__autocommit)
@@ -138,13 +146,14 @@ class Connection(object):
             num = cursor.execute(sql)
             cursor.close()
             return num
-        except pymysql.OperationalError:
+        except pymysql.OperationalError as e:
+            logging.error(str(e))
             self.open(self.__debug)
 
     def count(self, sql):
         try:
             if self.__debug:
-                print(f"sql: {sql}")
+                logging.info(f"sql: {sql}")
             if self.__conn is None:
                 self.open(self.__debug)
             self.__conn.autocommit(self.__autocommit)
@@ -156,13 +165,14 @@ class Connection(object):
                 total = v
             cursor.close()
             return total
-        except pymysql.OperationalError:
+        except pymysql.OperationalError as e:
+            logging.error(str(e))
             self.open(self.__debug)
 
     def sum(self, sql):
         try:
             if self.__debug:
-                print(f"sql: {sql}")
+                logging.info(f"sql: {sql}")
             if self.__conn is None:
                 self.open(self.__debug)
             self.__conn.autocommit(self.__autocommit)
@@ -174,13 +184,14 @@ class Connection(object):
                 total = v
             cursor.close()
             return total
-        except pymysql.OperationalError:
+        except pymysql.OperationalError as e:
+            logging.error(str(e))
             self.open(self.__debug)
 
     def min(self, sql):
         try:
             if self.__debug:
-                print(f"sql: {sql}")
+                logging.info(f"sql: {sql}")
             if self.__conn is None:
                 self.open(self.__debug)
             self.__conn.autocommit(self.__autocommit)
@@ -192,13 +203,14 @@ class Connection(object):
                 total = v
             cursor.close()
             return total
-        except pymysql.OperationalError:
+        except pymysql.OperationalError as e:
+            logging.error(str(e))
             self.open(self.__debug)
 
     def max(self, sql):
         try:
             if self.__debug:
-                print(f"sql: {sql}")
+                logging.info(f"sql: {sql}")
             if self.__conn is None:
                 self.open(self.__debug)
             self.__conn.autocommit(self.__autocommit)
@@ -210,13 +222,14 @@ class Connection(object):
                 total = v
             cursor.close()
             return total
-        except pymysql.OperationalError:
+        except pymysql.OperationalError as e:
+            logging.error(str(e))
             self.open(self.__debug)
 
     def average(self, sql):
         try:
             if self.__debug:
-                print(f"sql: {sql}")
+                logging.info(f"sql: {sql}")
             if self.__conn is None:
                 self.open(self.__debug)
             self.__conn.autocommit(self.__autocommit)
@@ -228,13 +241,14 @@ class Connection(object):
                 total = v
             cursor.close()
             return total
-        except pymysql.OperationalError:
+        except pymysql.OperationalError as e:
+            logging.error(str(e))
             self.open(self.__debug)
 
     def exists(self, sql):
         try:
             if self.__debug:
-                print(f"sql: {sql}")
+                logging.info(f"sql: {sql}")
             if self.__conn is None:
                 self.open(self.__debug)
             self.__conn.autocommit(self.__autocommit)
@@ -246,13 +260,14 @@ class Connection(object):
                 total = v
             cursor.close()
             return total == 1
-        except pymysql.OperationalError:
+        except pymysql.OperationalError as e:
+            logging.error(str(e))
             self.open(self.__debug)
 
     def column(self, sql):
         try:
             if self.__debug:
-                print(f"sql: {sql}")
+                logging.info(f"sql: {sql}")
             if self.__conn is None:
                 self.open(self.__debug)
             self.__conn.autocommit(self.__autocommit)
@@ -261,13 +276,14 @@ class Connection(object):
             result = cursor.fetchall()
             cursor.close()
             return result
-        except pymysql.OperationalError:
+        except pymysql.OperationalError as e:
+            logging.error(str(e))
             self.open(self.__debug)
 
     def scalar(self, sql):
         try:
             if self.__debug:
-                print(f"sql: {sql}")
+                logging.info(f"sql: {sql}")
             if self.__conn is None:
                 self.open(self.__debug)
             self.__conn.autocommit(self.__autocommit)
@@ -276,76 +292,83 @@ class Connection(object):
             result = cursor.fetchone()
             cursor.close()
             return result
-        except pymysql.OperationalError:
+        except pymysql.OperationalError as e:
+            logging.error(str(e))
             self.open(self.__debug)
 
     def begin(self):
         try:
             sql = "begin"
             if self.__debug:
-                print(f"sql: {sql}")
+                logging.info(f"sql: {sql}")
             if self.__conn is None:
                 self.open(self.__debug)
             cursor = self.__conn.cursor()
             cursor.execute(sql)
             cursor.close()
             self.__autocommit = False
-        except pymysql.OperationalError:
+        except pymysql.OperationalError as e:
+            logging.error(str(e))
             self.open(self.__debug)
 
     def rollback(self):
         try:
             sql = "rollback"
             if self.__debug:
-                print(f"sql: {sql}")
+                logging.info(f"sql: {sql}")
             cursor = self.__conn.cursor()
             cursor.execute(sql)
             cursor.close()
             self.__autocommit = True
-        except pymysql.OperationalError:
+        except pymysql.OperationalError as e:
+            logging.error(str(e))
             self.open(self.__debug)
 
     def commit(self):
         try:
             sql = "commit"
             if self.__debug:
-                print(f"sql: {sql}")
+                logging.info(f"sql: {sql}")
             cursor = self.__conn.cursor()
             cursor.execute(sql)
             cursor.close()
             self.__autocommit = True
-        except pymysql.OperationalError:
+        except pymysql.OperationalError as e:
+            logging.error(str(e))
             self.open(self.__debug)
 
     def savepoint(self, identifier):
         try:
             sql = f"savepoint {identifier}"
             if self.__debug:
-                print(f"sql: {sql}")
+                logging.info(f"sql: {sql}")
             cursor = self.__conn.cursor()
             cursor.execute(sql)
             cursor.close()
-        except pymysql.OperationalError:
+        except pymysql.OperationalError as e:
+            logging.error(str(e))
             self.open(self.__debug)
 
     def rollback_savepoint(self, identifier):
         try:
             sql = f"rollback to savepoint {identifier}"
             if self.__debug:
-                print(f"sql: {sql}")
+                logging.info(f"sql: {sql}")
             cursor = self.__conn.cursor()
             cursor.execute(sql)
             cursor.close()
-        except pymysql.OperationalError:
+        except pymysql.OperationalError as e:
+            logging.error(str(e))
             self.open(self.__debug)
 
     def release_savepoint(self, identifier):
         try:
             sql = f"release savepoint {identifier}"
             if self.__debug:
-                print(f"sql: {sql}")
+                logging.info(f"sql: {sql}")
             cursor = self.__conn.cursor()
             cursor.execute(sql)
             cursor.close()
-        except pymysql.OperationalError:
+        except pymysql.OperationalError as e:
+            logging.error(str(e))
             self.open(self.__debug)
