@@ -1,3 +1,4 @@
+import logging
 from queue import Queue
 from pymyorm.singleton import Singleton
 from pymyorm.connection import Connection
@@ -12,7 +13,7 @@ class ConnectionPool(object):
         self.__debug = False
         self.__ping = 3600
 
-    def create(self, host, port, user, password, database, charset='utf8', debug=False):
+    def create(self, host, port, user, password, database, charset='utf8', debug=False, lazy=True):
         if self.__pool is not None:
             del self.__pool
 
@@ -24,30 +25,35 @@ class ConnectionPool(object):
         self.__pool = Queue(self.__size)
         for _ in range(0, self.__size):
             conn = Connection(host=host, port=port, user=user, password=password, database=database, charset=charset)
-            conn.open(self.__debug)
+            if not lazy:
+                conn.open(self.__debug)
             conn.set_ping(self.__ping)
             self.put(conn)
 
     def put(self, conn):
         try:
             if self.__debug:
-                print('put connection into pool')
+                logging.info('put connection into pool')
+            if self.__pool is None:
+                return
             self.__pool.put(conn)
         except Exception as e:
             if self.__debug:
-                print('put connection into pool error')
+                logging.error(f'put connection into pool error: {str(e)}')
             raise e
 
     def get(self):
         try:
             if self.__debug:
-                print('get connection from pool')
+                logging.info('get connection from pool')
+            if self.__pool is None:
+                return None
             conn = self.__pool.get()
             conn.ping()
             return conn
         except Exception as e:
             if self.__debug:
-                print('get connection from pool error')
+                logging.error(f'get connection from pool error: {str(e)}')
             raise e
 
     def size(self, size):
