@@ -1,3 +1,5 @@
+import logging
+
 db = {
     'host': '127.0.0.1',
     'port': 3306,
@@ -7,3 +9,5 @@ db = {
     'charset': 'utf8',
     'debug': True
 }
+
+logging.basicConfig(level=logging.DEBUG)
