@@ -7,7 +7,9 @@ from threading import Thread
 
 # 定义一个线程任务
 class TaskThread(Thread):
+
     def __init__(self, name):
+        super().__init__()
         self.name = name
 
     def run(self):
@@ -17,21 +19,20 @@ class TaskThread(Thread):
         local.conn = pool.get()
         print(f"thread name={self.name} conn={local.conn}")
         time.sleep(3)
-        one = User.find().where(name=self.name).one()
-        print(one)
+        count = User.find().count()
+        print(count)
         pool.put(local.conn)
 
 
 if __name__ == '__main__':
 
     pool = ConnectionPool()
-    pool.size(size=10)
-    pool.debug(debug=True)
+    pool.size(size=3)
     pool.create(**db)
     stime = time.time()
     thread_list = []
-    for _ in range(10):
-        thread = TaskThread()
+    for i in range(2):
+        thread = TaskThread(str(i))
         thread_list.append(thread)
         thread.start()
     for thread in thread_list:
