@@ -6,7 +6,7 @@ from models.user import User
 
 if __name__ == '__main__':
 
-    Database().connect(**db)
+    Database.connect(**db)
 
     all = User.find().all()
     for one in all:
